@@ -131,7 +131,7 @@ bq_perform_upload <- function(x, values,
     fields <- as_bq_fields(fields)
     load$schema <- list(fields = as_json(fields))
   } else if (!bq_table_exists(x)) {
-    load$autodetect <- TRUE
+    load$autodetect <- unbox(TRUE)
   }
 
   config <- list(configuration = list(load = load))
@@ -224,13 +224,17 @@ bq_perform_load <- function(x,
   as_bq_job(res$jobReference)
 }
 
-
 #' @export
 #' @rdname api-perform
 #' @param query SQL query string.
 #' @param parameters Named list of parameters match to query parameters.
-#'   Parameter `x` will be matched to placeholder `@x`. See
-#'   <https://cloud.google.com/bigquery/docs/parameterized-queries>
+#'   Parameter `x` will be matched to placeholder `@x`.
+#'
+#'   Generally, you can supply R vectors and they will be automatically
+#'   converted to the correct type. If you need greater control, you can call
+#'   [bq_param_scalar()] or [bq_param_array()] explicitly.
+#'
+#'   See <https://cloud.google.com/bigquery/docs/parameterized-queries>
 #'   for more details.
 #' @param destination_table A [bq_table] where results should be stored.
 #'   If not supplied, results will be saved to a temporary table that lives
