@@ -64,6 +64,6 @@ show_json <- function(x) {
 
 #' @export
 print.bq_bytes <- function(x, ...) {
-  cat_line(prettyunits::pretty_bytes(x))
+  cat_line(prettyunits::pretty_bytes(unclass(x)))
 }
 # nocov end
