@@ -125,8 +125,8 @@ test_that("can parse arrays of structs", {
 # Complete files ----------------------------------------------------------
 
 replay_query <- function(name, sql) {
-  schema_path <- test_path(glue::glue("parse-schema-{name}.json"))
-  values_path <- test_path(glue::glue("parse-values-{name}.json"))
+  schema_path <- test_path(glue("parse-schema-{name}.json"))
+  values_path <- test_path(glue("parse-values-{name}.json"))
 
   if (!file.exists(schema_path)) {
     tbl <- bq_project_query(bq_test_project(), sql)
