@@ -1,4 +1,4 @@
-context("camelCase")
+context("camelCase.R")
 
 test_that("toCamel recursively renamed", {
   x1 <- list(a_b = 1, c_d = list(e_f = 2))
